@@ -26,6 +26,10 @@ def accepts(*verbs):
 class BasePublisher(object):
     CSRF = True
 
+    ACTION_PATTERN = r'\w+'
+    OBJECT_PATTERN = r'[-\w]+'
+    ARGUMENT_PATTERN = r'.+?'
+
     def __init__(self, request, *args, **kwargs):
         self.request = request
         self.args = args
@@ -64,23 +68,23 @@ class BasePublisher(object):
             name = cls.api_name
 
         return [
-            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/(?P<argument>.+?)/?$',
+            url(r'^object/(?P<object_id>%s)/(?P<action>%s)/(?P<argument>%s)/?$' % (cls.OBJECT_PATTERN, cls.ACTION_PATTERN, cls.ARGUMENT_PATTERN),
                 view,
                 name='%s_object_action_arg' % name
             ),
-            url(r'^object/(?P<object_id>[-\w]+)/(?P<action>\w+)/?$',
+            url(r'^object/(?P<object_id>%s)/(?P<action>%s)/?$' % (cls.OBJECT_PATTERN, cls.ACTION_PATTERN),
                 view,
                 name='%s_object_action' % name
             ),
-            url(r'^object/(?P<object_id>[-\w]+)/?$',
+            url(r'^object/(?P<object_id>%s)/?$' % (cls.OBJECT_PATTERN,),
                 view,
                 name='%s_object_default' % name
             ),
-            url(r'^(?P<action>\w+)/(?P<argument>.+?)/?$',
+            url(r'^(?P<action>%s)/(?P<argument>%s)/?$' % (cls.ACTION_PATTERN, cls.ARGUMENT_PATTERN),
                 view,
                 name='%s_list_action_arg' % name
             ),
-            url(r'^(?P<action>\w+)/?$',
+            url(r'^(?P<action>%s)/?$' % (cls.ACTION_PATTERN,),
                 view,
                 name='%s_list_action' % name
             ),
@@ -106,13 +110,12 @@ class BasePublisher(object):
         # Do we need to pass any of this?
         return self.execute(handler)
 
-    def execute(self, handler, **kwargs):
+    def execute(self, handler):
         '''This allows wrapping calls to handler functions'''
         try:
             return handler(self.request,
                 action=self.action,
                 object_id=self.object_id,
-                **kwargs
             )
         except http.BaseHttpResponse as response:
             return response
